@@ -454,7 +454,7 @@ add_notebook (GeditMultiNotebook *mnb,
 		GtkAllocation allocation;
 		GtkWidget *active_notebook = mnb->priv->active_notebook;
 
-		paned = gtk_hpaned_new ();
+		paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (paned);
 
 		/* First we remove the active container from its parent to make
@@ -540,6 +540,7 @@ remove_notebook (GeditMultiNotebook *mnb,
 	gtk_container_add (GTK_CONTAINER (grandpa),
 			   GTK_WIDGET (children->data));
 	g_object_unref (children->data);
+	g_list_free (children);
 
 	disconnect_notebook_signals (mnb, notebook);
 
@@ -690,7 +691,10 @@ gedit_multi_notebook_set_current_page (GeditMultiNotebook *mnb,
 	gint single_num = page_num;
 
 	g_return_if_fail (GEDIT_IS_MULTI_NOTEBOOK (mnb));
-	
+
+	if (mnb->priv->notebooks == NULL)
+		return;
+
 	for (l = mnb->priv->notebooks; l != NULL; l = g_list_next (l))
 	{
 		gint p;
@@ -757,11 +761,12 @@ gedit_multi_notebook_close_tabs (GeditMultiNotebook *mnb,
 						   GTK_WIDGET (l->data));
 
 			if (n != -1)
+			{
+				gedit_notebook_remove_tab (GEDIT_NOTEBOOK (nbs->data),
+				                           GEDIT_TAB (l->data));
 				break;
+			}
 		}
-
-		gedit_notebook_remove_tab (GEDIT_NOTEBOOK (nbs->data),
-					   GEDIT_TAB (l->data));
 	}
 }
 
