@@ -19,8 +19,7 @@ import os
 import re
 
 import cairo
-from gi.repository import Gtk, Gdk, Gio, GLib, GtkSource, Gedit
-import glib
+from gi.repository import Gtk, Gdk, Gio, GtkSource, Gedit
 
 from library import Library
 from snippet import Snippet
@@ -63,7 +62,7 @@ class Document:
         # to the view and the plugin instance, disconnect all signal handlers
         def stop(self):
                 if self.timeout_update_id != 0:
-                        GLib.source_remove(self.timeout_update_id)
+                        GObject.source_remove(self.timeout_update_id)
                         self.timeout_update_id = 0
                         del self.update_placeholders[:]
                         del self.jump_placeholders[:]
@@ -729,7 +728,7 @@ class Document:
                         self.jump_placeholders.append((self.active_placeholder, current))
 
                         if self.timeout_update_id == 0:
-                                self.timeout_update_id = glib.timeout_add(0,
+                                self.timeout_update_id = GObject.timeout_add(0,
                                                 self.update_snippet_contents)
 
         def on_buffer_changed(self, buf):
@@ -740,7 +739,7 @@ class Document:
                                 self.update_placeholders.append(current)
 
                         if self.timeout_update_id == 0:
-                                self.timeout_update_id = glib.timeout_add(0, \
+                                self.timeout_update_id = GObject.timeout_add(0, \
                                                 self.update_snippet_contents)
 
         def on_buffer_insert_text(self, buf, piter, text, length):
